@@ -27,16 +27,9 @@ class TestPreferencesDialog(nfoview.TestCase):
         self.dialog.run()
 
     def setup_method(self, method):
-        window1 = nfoview.Window(self.new_nfo_file())
-        window2 = nfoview.Window(self.new_nfo_file())
-        nfoview.main.windows.append(window1)
-        nfoview.main.windows.append(window2)
         self.dialog = nfoview.PreferencesDialog(Gtk.Window())
         self.rgba = Gdk.RGBA(red=1, green=0, blue=1)
 
-    def teardown_method(self, method):
-        nfoview.main.windows = []
-
     def test__on_bg_color_button_color_set(self):
         store = self.dialog._scheme_combo.get_model()
         self.dialog._scheme_combo.set_active(len(store)-1)
@@ -50,7 +43,7 @@ class TestPreferencesDialog(nfoview.TestCase):
         self.dialog._fg_color_button.emit("color-set")
 
     def test__on_font_button_font_set(self):
-        self.dialog._font_button.set_font_name("monospace 8")
+        self.dialog._font_button.set_font("monospace 8")
         self.dialog._font_button.emit("font-set")
 
     def test__on_line_spacing_spin_value_changed(self):
